@@ -19,7 +19,8 @@
 #ifndef KIG_KIG_H
 #define KIG_KIG_H
 
-#include <kparts/mainwindow.h>
+#include <KParts/MainWindow>
+#include <KParts/ReadWritePart>
 
 class KRecentFilesAction;
 
@@ -46,15 +47,14 @@ class Kig : public KParts::MainWindow
    * Open file in this window
    * \param file file to open
    */
-  void load( const KUrl& file );
+  void load( const QUrl &file );
 
   /**
    * this opens the file specified in \p s in a new window
    *
    * \param s the url of the file to open
    */
-  virtual void openUrl( const QString& s ) { openUrl( KUrl( s ) ); }
-  void openUrl( const KUrl& s );
+  void openUrl( const QUrl &s );
 
  protected:
 
