@@ -50,7 +50,7 @@ KigPainter::KigPainter( const ScreenInfo& si, QPaintDevice* device,
   : mP ( device ),
     color( Qt::blue ),
     style( Qt::SolidLine ),
-    pointstyle( 0 ),
+    pointstyle( Kig::Round ),
     width( -1 ),
     brushStyle( Qt::NoBrush ),
     brushColor( Qt::blue ),
@@ -104,7 +104,7 @@ void KigPainter::drawFatPoint( const Coordinate& p )
   mP.setPen( QPen( color, 1, style ) );
   switch ( pointstyle )
   {
-    case 0:
+    case Kig::Round:
     {
       double radius = twidth * pixelWidth();
       setBrushStyle( Qt::SolidPattern );
@@ -118,7 +118,7 @@ void KigPainter::drawFatPoint( const Coordinate& p )
       if( mNeedOverlay ) mOverlay.push_back( qr );
       break;
     }
-    case 1:
+    case Kig::RoundEmpty:
     {
       double radius = twidth * pixelWidth();
       setBrushStyle( Qt::NoBrush );
@@ -132,7 +132,7 @@ void KigPainter::drawFatPoint( const Coordinate& p )
       if( mNeedOverlay ) mOverlay.push_back( qr );
       break;
     }
-    case 2:
+    case Kig::Rectangular:
     {
       double radius = twidth * pixelWidth();
       Coordinate rad( radius, radius );
@@ -146,7 +146,7 @@ void KigPainter::drawFatPoint( const Coordinate& p )
       if( mNeedOverlay ) mOverlay.push_back( qr );
       break;
     }
-    case 3:
+    case Kig::RectangularEmpty:
     {
       double radius = twidth * pixelWidth();
       Coordinate rad( radius, radius );
@@ -159,7 +159,7 @@ void KigPainter::drawFatPoint( const Coordinate& p )
       if( mNeedOverlay ) mOverlay.push_back( qr );
       break;
     }
-    case 4:
+    case Kig::Cross:
     {
       double radius = twidth * pixelWidth();
       Coordinate rad( radius, radius );
@@ -174,6 +174,10 @@ void KigPainter::drawFatPoint( const Coordinate& p )
       if( mNeedOverlay ) mOverlay.push_back( qr );
       break;
     }
+    default:
+    {
+      break;
+    }
   }
   mP.setPen( QPen( color, twidth, style ) );
 }
@@ -235,7 +239,7 @@ void KigPainter::setWidth( int c )
   mP.setPen( QPen( color, width == -1 ? 1 : width, style ) );
 }
 
-void KigPainter::setPointStyle( int p )
+void KigPainter::setPointStyle( Kig::PointStyle p )
 {
   pointstyle = p;
 }
